@@ -4,7 +4,7 @@ use warnings;
 
 package Mxpress::PDF {
 	BEGIN {
-		our $VERSION = '0.16';
+		our $VERSION = '0.17';
 		our $AUTHORITY = 'cpan:LNATION';
 	};
 	use Zydeco;
@@ -828,7 +828,11 @@ package Mxpress::PDF {
 				my ($x, $y, $w, $h) = $self->set_position(@{$placeholder->{position}});
 				$args{page_offset} = 0;
 				my $one_toc_link = $self->outlines->[0]->font->size + $self->toc_line_offset/mm;
-				my $total_height = ($self->count * $one_toc_link) - ($h + ($self->file->page->h * ($self->file->page->columns - 1)));
+				$self->file->page($placeholder->{page});
+				my $total_height = ($self->count * $one_toc_link) - ($h + ($self->file->page->columns > 1 
+					? ($self->file->page->h * ($self->file->page->columns - $self->file->page->column)) 
+					: 0
+				));
 				while ($total_height > 0) {
 					$args{page_offset}++;
 					$self->file->add_page(num => $placeholder->{page}->num + $args{page_offset});
@@ -1026,7 +1030,7 @@ Mxpress::PDF - PDF
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =cut
 
